@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -50,11 +50,9 @@ typedef struct
     SDL_Surface *window;
 } SW_RenderData;
 
-
-static SDL_Surface *
-SW_ActivateRenderer(SDL_Renderer * renderer)
+static SDL_Surface *SW_ActivateRenderer(SDL_Renderer *renderer)
 {
-    SW_RenderData *data = (SW_RenderData *) renderer->driverdata;
+    SW_RenderData *data = (SW_RenderData *)renderer->driverdata;
 
     if (!data->surface) {
         data->surface = data->window;
@@ -68,10 +66,9 @@ SW_ActivateRenderer(SDL_Renderer * renderer)
     return data->surface;
 }
 
-static void
-SW_WindowEvent(SDL_Renderer * renderer, const SDL_WindowEvent *event)
+static void SW_WindowEvent(SDL_Renderer *renderer, const SDL_WindowEvent *event)
 {
-    SW_RenderData *data = (SW_RenderData *) renderer->driverdata;
+    SW_RenderData *data = (SW_RenderData *)renderer->driverdata;
 
     if (event->event == SDL_WINDOWEVENT_SIZE_CHANGED) {
         data->surface = NULL;
@@ -79,10 +76,9 @@ SW_WindowEvent(SDL_Renderer * renderer, const SDL_WindowEvent *event)
     }
 }
 
-static int
-SW_GetOutputSize(SDL_Renderer * renderer, int *w, int *h)
+static int SW_GetOutputSize(SDL_Renderer *renderer, int *w, int *h)
 {
-    SW_RenderData *data = (SW_RenderData *) renderer->driverdata;
+    SW_RenderData *data = (SW_RenderData *)renderer->driverdata;
 
     if (data->surface) {
         if (w) {
@@ -95,21 +91,19 @@ SW_GetOutputSize(SDL_Renderer * renderer, int *w, int *h)
     }
 
     if (renderer->window) {
-        SDL_GetWindowSize(renderer->window, w, h);
+        SDL_GetWindowSizeInPixels(renderer->window, w, h);
         return 0;
     }
 
     return SDL_SetError("Software renderer doesn't have an output surface");
 }
 
-static int
-SW_CreateTexture(SDL_Renderer * renderer, SDL_Texture * texture)
+static int SW_CreateTexture(SDL_Renderer *renderer, SDL_Texture *texture)
 {
     int bpp;
     Uint32 Rmask, Gmask, Bmask, Amask;
 
-    if (!SDL_PixelFormatEnumToMasks
-        (texture->format, &bpp, &Rmask, &Gmask, &Bmask, &Amask)) {
+    if (!SDL_PixelFormatEnumToMasks(texture->format, &bpp, &Rmask, &Gmask, &Bmask, &Amask)) {
         return SDL_SetError("Unknown texture format");
     }
 
@@ -133,81 +127,76 @@ SW_CreateTexture(SDL_Renderer * renderer, SDL_Texture * texture)
     return 0;
 }
 
-static int
-SW_UpdateTexture(SDL_Renderer * renderer, SDL_Texture * texture,
-                 const SDL_Rect * rect, const void *pixels, int pitch)
+static int SW_UpdateTexture(SDL_Renderer *renderer, SDL_Texture *texture,
+                            const SDL_Rect *rect, const void *pixels, int pitch)
 {
-    SDL_Surface *surface = (SDL_Surface *) texture->driverdata;
+    SDL_Surface *surface = (SDL_Surface *)texture->driverdata;
     Uint8 *src, *dst;
     int row;
     size_t length;
 
-    if(SDL_MUSTLOCK(surface))
+    if (SDL_MUSTLOCK(surface)) {
         SDL_LockSurface(surface);
-    src = (Uint8 *) pixels;
-    dst = (Uint8 *) surface->pixels +
-                        rect->y * surface->pitch +
-                        rect->x * surface->format->BytesPerPixel;
-    length = rect->w * surface->format->BytesPerPixel;
+    }
+    src = (Uint8 *)pixels;
+    dst = (Uint8 *)surface->pixels +
+          rect->y * surface->pitch +
+          rect->x * surface->format->BytesPerPixel;
+    length = (size_t)rect->w * surface->format->BytesPerPixel;
     for (row = 0; row < rect->h; ++row) {
         SDL_memcpy(dst, src, length);
         src += pitch;
         dst += surface->pitch;
     }
-    if(SDL_MUSTLOCK(surface))
+    if (SDL_MUSTLOCK(surface)) {
         SDL_UnlockSurface(surface);
+    }
     return 0;
 }
 
-static int
-SW_LockTexture(SDL_Renderer * renderer, SDL_Texture * texture,
-               const SDL_Rect * rect, void **pixels, int *pitch)
+static int SW_LockTexture(SDL_Renderer *renderer, SDL_Texture *texture,
+                          const SDL_Rect *rect, void **pixels, int *pitch)
 {
-    SDL_Surface *surface = (SDL_Surface *) texture->driverdata;
+    SDL_Surface *surface = (SDL_Surface *)texture->driverdata;
 
     *pixels =
-        (void *) ((Uint8 *) surface->pixels + rect->y * surface->pitch +
-                  rect->x * surface->format->BytesPerPixel);
+        (void *)((Uint8 *)surface->pixels + rect->y * surface->pitch +
+                 rect->x * surface->format->BytesPerPixel);
     *pitch = surface->pitch;
     return 0;
 }
 
-static void
-SW_UnlockTexture(SDL_Renderer * renderer, SDL_Texture * texture)
+static void SW_UnlockTexture(SDL_Renderer *renderer, SDL_Texture *texture)
 {
 }
 
-static void
-SW_SetTextureScaleMode(SDL_Renderer * renderer, SDL_Texture * texture, SDL_ScaleMode scaleMode)
+static void SW_SetTextureScaleMode(SDL_Renderer *renderer, SDL_Texture *texture, SDL_ScaleMode scaleMode)
 {
 }
 
-static int
-SW_SetRenderTarget(SDL_Renderer * renderer, SDL_Texture * texture)
+static int SW_SetRenderTarget(SDL_Renderer *renderer, SDL_Texture *texture)
 {
-    SW_RenderData *data = (SW_RenderData *) renderer->driverdata;
+    SW_RenderData *data = (SW_RenderData *)renderer->driverdata;
 
     if (texture) {
-        data->surface = (SDL_Surface *) texture->driverdata;
+        data->surface = (SDL_Surface *)texture->driverdata;
     } else {
         data->surface = data->window;
     }
     return 0;
 }
 
-static int
-SW_QueueSetViewport(SDL_Renderer * renderer, SDL_RenderCommand *cmd)
+static int SW_QueueSetViewport(SDL_Renderer *renderer, SDL_RenderCommand *cmd)
 {
-    return 0;  /* nothing to do in this backend. */
+    return 0; /* nothing to do in this backend. */
 }
 
-static int
-SW_QueueDrawPoints(SDL_Renderer * renderer, SDL_RenderCommand *cmd, const SDL_FPoint * points, int count)
+static int SW_QueueDrawPoints(SDL_Renderer *renderer, SDL_RenderCommand *cmd, const SDL_FPoint *points, int count)
 {
-    SDL_Point *verts = (SDL_Point *) SDL_AllocateRenderVertices(renderer, count * sizeof (SDL_Point), 0, &cmd->data.draw.first);
+    SDL_Point *verts = (SDL_Point *)SDL_AllocateRenderVertices(renderer, count * sizeof(SDL_Point), 0, &cmd->data.draw.first);
     int i;
 
-    if (!verts) {
+    if (verts == NULL) {
         return -1;
     }
 
@@ -221,13 +210,12 @@ SW_QueueDrawPoints(SDL_Renderer * renderer, SDL_RenderCommand *cmd, const SDL_FP
     return 0;
 }
 
-static int
-SW_QueueFillRects(SDL_Renderer * renderer, SDL_RenderCommand *cmd, const SDL_FRect * rects, int count)
+static int SW_QueueFillRects(SDL_Renderer *renderer, SDL_RenderCommand *cmd, const SDL_FRect *rects, int count)
 {
-    SDL_Rect *verts = (SDL_Rect *) SDL_AllocateRenderVertices(renderer, count * sizeof (SDL_Rect), 0, &cmd->data.draw.first);
+    SDL_Rect *verts = (SDL_Rect *)SDL_AllocateRenderVertices(renderer, count * sizeof(SDL_Rect), 0, &cmd->data.draw.first);
     int i;
 
-    if (!verts) {
+    if (verts == NULL) {
         return -1;
     }
 
@@ -243,13 +231,12 @@ SW_QueueFillRects(SDL_Renderer * renderer, SDL_RenderCommand *cmd, const SDL_FRe
     return 0;
 }
 
-static int
-SW_QueueCopy(SDL_Renderer * renderer, SDL_RenderCommand *cmd, SDL_Texture * texture,
-             const SDL_Rect * srcrect, const SDL_FRect * dstrect)
+static int SW_QueueCopy(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *texture,
+                        const SDL_Rect *srcrect, const SDL_FRect *dstrect)
 {
-    SDL_Rect *verts = (SDL_Rect *) SDL_AllocateRenderVertices(renderer, 2 * sizeof (SDL_Rect), 0, &cmd->data.draw.first);
+    SDL_Rect *verts = (SDL_Rect *)SDL_AllocateRenderVertices(renderer, 2 * sizeof(SDL_Rect), 0, &cmd->data.draw.first);
 
-    if (!verts) {
+    if (verts == NULL) {
         return -1;
     }
 
@@ -277,14 +264,13 @@ typedef struct CopyExData
     float scale_y;
 } CopyExData;
 
-static int
-SW_QueueCopyEx(SDL_Renderer * renderer, SDL_RenderCommand *cmd, SDL_Texture * texture,
-               const SDL_Rect * srcrect, const SDL_FRect * dstrect,
-               const double angle, const SDL_FPoint *center, const SDL_RendererFlip flip, float scale_x, float scale_y)
+static int SW_QueueCopyEx(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *texture,
+                          const SDL_Rect *srcrect, const SDL_FRect *dstrect,
+                          const double angle, const SDL_FPoint *center, const SDL_RendererFlip flip, float scale_x, float scale_y)
 {
-    CopyExData *verts = (CopyExData *) SDL_AllocateRenderVertices(renderer, sizeof (CopyExData), 0, &cmd->data.draw.first);
+    CopyExData *verts = (CopyExData *)SDL_AllocateRenderVertices(renderer, sizeof(CopyExData), 0, &cmd->data.draw.first);
 
-    if (!verts) {
+    if (verts == NULL) {
         return -1;
     }
 
@@ -305,18 +291,17 @@ SW_QueueCopyEx(SDL_Renderer * renderer, SDL_RenderCommand *cmd, SDL_Texture * te
     return 0;
 }
 
-static int
-Blit_to_Screen(SDL_Surface *src, SDL_Rect *srcrect, SDL_Surface *surface, SDL_Rect *dstrect,
-        float scale_x, float scale_y, SDL_ScaleMode scaleMode)
+static int Blit_to_Screen(SDL_Surface *src, SDL_Rect *srcrect, SDL_Surface *surface, SDL_Rect *dstrect,
+                          float scale_x, float scale_y, SDL_ScaleMode scaleMode)
 {
     int retval;
     /* Renderer scaling, if needed */
     if (scale_x != 1.0f || scale_y != 1.0f) {
         SDL_Rect r;
-        r.x = (int)((float) dstrect->x * scale_x);
-        r.y = (int)((float) dstrect->y * scale_y);
-        r.w = (int)((float) dstrect->w * scale_x);
-        r.h = (int)((float) dstrect->h * scale_y);
+        r.x = (int)((float)dstrect->x * scale_x);
+        r.y = (int)((float)dstrect->y * scale_y);
+        r.w = (int)((float)dstrect->w * scale_x);
+        r.h = (int)((float)dstrect->h * scale_y);
         retval = SDL_PrivateUpperBlitScaled(src, srcrect, surface, &r, scaleMode);
     } else {
         retval = SDL_BlitSurface(src, srcrect, surface, dstrect);
@@ -324,12 +309,11 @@ Blit_to_Screen(SDL_Surface *src, SDL_Rect *srcrect, SDL_Surface *surface, SDL_Re
     return retval;
 }
 
-static int
-SW_RenderCopyEx(SDL_Renderer * renderer, SDL_Surface *surface, SDL_Texture * texture,
-                const SDL_Rect * srcrect, const SDL_Rect * final_rect,
-                const double angle, const SDL_FPoint * center, const SDL_RendererFlip flip, float scale_x, float scale_y)
+static int SW_RenderCopyEx(SDL_Renderer *renderer, SDL_Surface *surface, SDL_Texture *texture,
+                           const SDL_Rect *srcrect, const SDL_Rect *final_rect,
+                           const double angle, const SDL_FPoint *center, const SDL_RendererFlip flip, float scale_x, float scale_y)
 {
-    SDL_Surface *src = (SDL_Surface *) texture->driverdata;
+    SDL_Surface *src = (SDL_Surface *)texture->driverdata;
     SDL_Rect tmp_rect;
     SDL_Surface *src_clone, *src_rotated, *src_scaled;
     SDL_Surface *mask = NULL, *mask_rotated = NULL;
@@ -340,7 +324,7 @@ SW_RenderCopyEx(SDL_Renderer * renderer, SDL_Surface *surface, SDL_Texture * tex
     int blitRequired = SDL_FALSE;
     int isOpaque = SDL_FALSE;
 
-    if (!surface) {
+    if (surface == NULL) {
         return -1;
     }
 
@@ -439,18 +423,18 @@ SW_RenderCopyEx(SDL_Renderer * renderer, SDL_Surface *surface, SDL_Texture * tex
         double cangle, sangle;
 
         SDLgfx_rotozoomSurfaceSizeTrig(tmp_rect.w, tmp_rect.h, angle, center,
-                &rect_dest, &cangle, &sangle);
+                                       &rect_dest, &cangle, &sangle);
         src_rotated = SDLgfx_rotateSurface(src_clone, angle,
-                (texture->scaleMode == SDL_ScaleModeNearest) ? 0 : 1, flip & SDL_FLIP_HORIZONTAL, flip & SDL_FLIP_VERTICAL,
-                &rect_dest, cangle, sangle, center);
+                                           (texture->scaleMode == SDL_ScaleModeNearest) ? 0 : 1, flip & SDL_FLIP_HORIZONTAL, flip & SDL_FLIP_VERTICAL,
+                                           &rect_dest, cangle, sangle, center);
         if (src_rotated == NULL) {
             retval = -1;
         }
         if (!retval && mask != NULL) {
             /* The mask needed for the NONE blend mode gets rotated with the same parameters. */
             mask_rotated = SDLgfx_rotateSurface(mask, angle,
-                    SDL_FALSE, 0, 0,
-                    &rect_dest, cangle, sangle, center);
+                                                SDL_FALSE, 0, 0,
+                                                &rect_dest, cangle, sangle, center);
             if (mask_rotated == NULL) {
                 retval = -1;
             }
@@ -533,7 +517,6 @@ SW_RenderCopyEx(SDL_Renderer * renderer, SDL_Surface *surface, SDL_Texture * tex
     return retval;
 }
 
-
 typedef struct GeometryFillData
 {
     SDL_Point dst;
@@ -547,19 +530,18 @@ typedef struct GeometryCopyData
     SDL_Color color;
 } GeometryCopyData;
 
-static int
-SW_QueueGeometry(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *texture,
-        const float *xy, int xy_stride, const SDL_Color *color, int color_stride, const float *uv, int uv_stride,
-        int num_vertices, const void *indices, int num_indices, int size_indices,
-        float scale_x, float scale_y)
+static int SW_QueueGeometry(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *texture,
+                            const float *xy, int xy_stride, const SDL_Color *color, int color_stride, const float *uv, int uv_stride,
+                            int num_vertices, const void *indices, int num_indices, int size_indices,
+                            float scale_x, float scale_y)
 {
     int i;
     int count = indices ? num_indices : num_vertices;
     void *verts;
-    int sz = texture ? sizeof (GeometryCopyData) : sizeof (GeometryFillData);
+    size_t sz = texture != NULL ? sizeof(GeometryCopyData) : sizeof(GeometryFillData);
 
-    verts = (void *) SDL_AllocateRenderVertices(renderer, count * sz, 0, &cmd->data.draw.first);
-    if (!verts) {
+    verts = SDL_AllocateRenderVertices(renderer, count * sz, 0, &cmd->data.draw.first);
+    if (verts == NULL) {
         return -1;
     }
 
@@ -567,7 +549,7 @@ SW_QueueGeometry(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *te
     size_indices = indices ? size_indices : 0;
 
     if (texture) {
-        GeometryCopyData *ptr = (GeometryCopyData *) verts;
+        GeometryCopyData *ptr = (GeometryCopyData *)verts;
         for (i = 0; i < count; i++) {
             int j;
             float *xy_;
@@ -583,10 +565,10 @@ SW_QueueGeometry(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *te
                 j = i;
             }
 
-            xy_ = (float *)((char*)xy + j * xy_stride);
-            col_ = *(SDL_Color *)((char*)color + j * color_stride);
+            xy_ = (float *)((char *)xy + j * xy_stride);
+            col_ = *(SDL_Color *)((char *)color + j * color_stride);
 
-            uv_ = (float *)((char*)uv + j * uv_stride);
+            uv_ = (float *)((char *)uv + j * uv_stride);
 
             ptr->src.x = (int)(uv_[0] * texture->w);
             ptr->src.y = (int)(uv_[1] * texture->h);
@@ -598,9 +580,9 @@ SW_QueueGeometry(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *te
             ptr->color = col_;
 
             ptr++;
-       }
+        }
     } else {
-        GeometryFillData *ptr = (GeometryFillData *) verts;
+        GeometryFillData *ptr = (GeometryFillData *)verts;
 
         for (i = 0; i < count; i++) {
             int j;
@@ -616,8 +598,8 @@ SW_QueueGeometry(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *te
                 j = i;
             }
 
-            xy_ = (float *)((char*)xy + j * xy_stride);
-            col_ = *(SDL_Color *)((char*)color + j * color_stride);
+            xy_ = (float *)((char *)xy + j * xy_stride);
+            col_ = *(SDL_Color *)((char *)color + j * color_stride);
 
             ptr->dst.x = (int)(xy_[0] * scale_x);
             ptr->dst.y = (int)(xy_[1] * scale_y);
@@ -626,13 +608,12 @@ SW_QueueGeometry(SDL_Renderer *renderer, SDL_RenderCommand *cmd, SDL_Texture *te
             ptr->color = col_;
 
             ptr++;
-       }
+        }
     }
     return 0;
 }
 
-static void
-PrepTextureForCopy(const SDL_RenderCommand *cmd)
+static void PrepTextureForCopy(const SDL_RenderCommand *cmd)
 {
     const Uint8 r = cmd->data.draw.r;
     const Uint8 g = cmd->data.draw.g;
@@ -640,7 +621,7 @@ PrepTextureForCopy(const SDL_RenderCommand *cmd)
     const Uint8 a = cmd->data.draw.a;
     const SDL_BlendMode blend = cmd->data.draw.blend;
     SDL_Texture *texture = cmd->data.draw.texture;
-    SDL_Surface *surface = (SDL_Surface *) texture->driverdata;
+    SDL_Surface *surface = (SDL_Surface *)texture->driverdata;
     const SDL_bool colormod = ((r & g & b) != 0xFF);
     const SDL_bool alphamod = (a != 0xFF);
     const SDL_bool blending = ((blend == SDL_BLENDMODE_ADD) || (blend == SDL_BLENDMODE_MOD) || (blend == SDL_BLENDMODE_MUL));
@@ -655,13 +636,12 @@ PrepTextureForCopy(const SDL_RenderCommand *cmd)
     SDL_SetSurfaceBlendMode(surface, blend);
 }
 
-static void
-SetDrawState(SDL_Surface *surface, SW_DrawStateCache *drawstate)
+static void SetDrawState(SDL_Surface *surface, SW_DrawStateCache *drawstate)
 {
     if (drawstate->surface_cliprect_dirty) {
         const SDL_Rect *viewport = drawstate->viewport;
         const SDL_Rect *cliprect = drawstate->cliprect;
-        SDL_assert(viewport != NULL);  /* the higher level should have forced a SDL_RENDERCMD_SETVIEWPORT */
+        SDL_assert_release(viewport != NULL); /* the higher level should have forced a SDL_RENDERCMD_SETVIEWPORT */
 
         if (cliprect != NULL) {
             SDL_Rect clip_rect;
@@ -678,13 +658,12 @@ SetDrawState(SDL_Surface *surface, SW_DrawStateCache *drawstate)
     }
 }
 
-static int
-SW_RunCommandQueue(SDL_Renderer * renderer, SDL_RenderCommand *cmd, void *vertices, size_t vertsize)
+static int SW_RunCommandQueue(SDL_Renderer *renderer, SDL_RenderCommand *cmd, void *vertices, size_t vertsize)
 {
     SDL_Surface *surface = SW_ActivateRenderer(renderer);
     SW_DrawStateCache drawstate;
 
-    if (!surface) {
+    if (surface == NULL) {
         return -1;
     }
 
@@ -952,15 +931,14 @@ SW_RunCommandQueue(SDL_Renderer * renderer, SDL_RenderCommand *cmd, void *vertic
     return 0;
 }
 
-static int
-SW_RenderReadPixels(SDL_Renderer * renderer, const SDL_Rect * rect,
-                    Uint32 format, void * pixels, int pitch)
+static int SW_RenderReadPixels(SDL_Renderer *renderer, const SDL_Rect *rect,
+                               Uint32 format, void *pixels, int pitch)
 {
     SDL_Surface *surface = SW_ActivateRenderer(renderer);
     Uint32 src_format;
     void *src_pixels;
 
-    if (!surface) {
+    if (surface == NULL) {
         return -1;
     }
 
@@ -968,68 +946,64 @@ SW_RenderReadPixels(SDL_Renderer * renderer, const SDL_Rect * rect,
      * SDL_RenderReadPixels.
      */
 
-    if (rect->x < 0 || rect->x+rect->w > surface->w ||
-        rect->y < 0 || rect->y+rect->h > surface->h) {
+    if (rect->x < 0 || rect->x + rect->w > surface->w ||
+        rect->y < 0 || rect->y + rect->h > surface->h) {
         return SDL_SetError("Tried to read outside of surface bounds");
     }
 
     src_format = surface->format->format;
-    src_pixels = (void*)((Uint8 *) surface->pixels +
-                    rect->y * surface->pitch +
-                    rect->x * surface->format->BytesPerPixel);
+    src_pixels = (void *)((Uint8 *)surface->pixels +
+                          rect->y * surface->pitch +
+                          rect->x * surface->format->BytesPerPixel);
 
     return SDL_ConvertPixels(rect->w, rect->h,
                              src_format, src_pixels, surface->pitch,
                              format, pixels, pitch);
 }
 
-static int
-SW_RenderPresent(SDL_Renderer * renderer)
+static int SW_RenderPresent(SDL_Renderer *renderer)
 {
     SDL_Window *window = renderer->window;
 
-    if (!window) {
+    if (window == NULL) {
         return -1;
     }
     return SDL_UpdateWindowSurface(window);
 }
 
-static void
-SW_DestroyTexture(SDL_Renderer * renderer, SDL_Texture * texture)
+static void SW_DestroyTexture(SDL_Renderer *renderer, SDL_Texture *texture)
 {
-    SDL_Surface *surface = (SDL_Surface *) texture->driverdata;
+    SDL_Surface *surface = (SDL_Surface *)texture->driverdata;
 
     SDL_FreeSurface(surface);
 }
 
-static void
-SW_DestroyRenderer(SDL_Renderer * renderer)
+static void SW_DestroyRenderer(SDL_Renderer *renderer)
 {
-    SW_RenderData *data = (SW_RenderData *) renderer->driverdata;
+    SW_RenderData *data = (SW_RenderData *)renderer->driverdata;
 
     SDL_free(data);
     SDL_free(renderer);
 }
 
-SDL_Renderer *
-SW_CreateRendererForSurface(SDL_Surface * surface)
+SDL_Renderer *SW_CreateRendererForSurface(SDL_Surface *surface)
 {
     SDL_Renderer *renderer;
     SW_RenderData *data;
 
-    if (!surface) {
+    if (surface == NULL) {
         SDL_InvalidParamError("surface");
         return NULL;
     }
 
-    renderer = (SDL_Renderer *) SDL_calloc(1, sizeof(*renderer));
-    if (!renderer) {
+    renderer = (SDL_Renderer *)SDL_calloc(1, sizeof(*renderer));
+    if (renderer == NULL) {
         SDL_OutOfMemory();
         return NULL;
     }
 
-    data = (SW_RenderData *) SDL_calloc(1, sizeof(*data));
-    if (!data) {
+    data = (SW_RenderData *)SDL_calloc(1, sizeof(*data));
+    if (data == NULL) {
         SW_DestroyRenderer(renderer);
         SDL_OutOfMemory();
         return NULL;
@@ -1046,9 +1020,9 @@ SW_CreateRendererForSurface(SDL_Surface * surface)
     renderer->SetTextureScaleMode = SW_SetTextureScaleMode;
     renderer->SetRenderTarget = SW_SetRenderTarget;
     renderer->QueueSetViewport = SW_QueueSetViewport;
-    renderer->QueueSetDrawColor = SW_QueueSetViewport;  /* SetViewport and SetDrawColor are (currently) no-ops. */
+    renderer->QueueSetDrawColor = SW_QueueSetViewport; /* SetViewport and SetDrawColor are (currently) no-ops. */
     renderer->QueueDrawPoints = SW_QueueDrawPoints;
-    renderer->QueueDrawLines = SW_QueueDrawPoints;  /* lines and points queue vertices the same way. */
+    renderer->QueueDrawLines = SW_QueueDrawPoints; /* lines and points queue vertices the same way. */
     renderer->QueueFillRects = SW_QueueFillRects;
     renderer->QueueCopy = SW_QueueCopy;
     renderer->QueueCopyEx = SW_QueueCopyEx;
@@ -1066,8 +1040,7 @@ SW_CreateRendererForSurface(SDL_Surface * surface)
     return renderer;
 }
 
-static SDL_Renderer *
-SW_CreateRenderer(SDL_Window * window, Uint32 flags)
+static SDL_Renderer *SW_CreateRenderer(SDL_Window *window, Uint32 flags)
 {
     const char *hint;
     SDL_Surface *surface;
@@ -1075,7 +1048,7 @@ SW_CreateRenderer(SDL_Window * window, Uint32 flags)
 
     /* Set the vsync hint based on our flags, if it's not already set */
     hint = SDL_GetHint(SDL_HINT_RENDER_VSYNC);
-    if (!hint || !*hint) {
+    if (hint == NULL || !*hint) {
         no_hint_set = SDL_TRUE;
     } else {
         no_hint_set = SDL_FALSE;
@@ -1092,7 +1065,7 @@ SW_CreateRenderer(SDL_Window * window, Uint32 flags)
         SDL_SetHint(SDL_HINT_RENDER_VSYNC, "");
     }
 
-    if (!surface) {
+    if (surface == NULL) {
         return NULL;
     }
     return SW_CreateRendererForSurface(surface);
