@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -18,17 +18,23 @@
      misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
 */
+
+#ifndef SDL_timer_c_h_
+#define SDL_timer_c_h_
+
 #include "../SDL_internal.h"
 
 /* Useful functions and variables from SDL_timer.c */
 #include "SDL_timer.h"
 
 #define ROUND_RESOLUTION(X) \
-    (((X+TIMER_RESOLUTION-1)/TIMER_RESOLUTION)*TIMER_RESOLUTION)
+    (((X + TIMER_RESOLUTION - 1) / TIMER_RESOLUTION) * TIMER_RESOLUTION)
 
 extern void SDL_TicksInit(void);
 extern void SDL_TicksQuit(void);
 extern int SDL_TimerInit(void);
 extern void SDL_TimerQuit(void);
 
+#endif /* SDL_timer_c_h_ */
+
 /* vi: set ts=4 sw=4 expandtab: */
