@@ -25,8 +25,7 @@
 #include "SDL_cocoavideo.h"
 #include "../../events/SDL_clipboardevents_c.h"
 
-int
-Cocoa_SetClipboardText(_THIS, const char *text)
+int Cocoa_SetClipboardText(_THIS, const char *text)
 { @autoreleasepool
 {
     SDL_VideoData *data = (__bridge SDL_VideoData *) _this->driverdata;
@@ -44,8 +43,7 @@ Cocoa_SetClipboardText(_THIS, const char *text)
     return 0;
 }}
 
-char *
-Cocoa_GetClipboardText(_THIS)
+char *Cocoa_GetClipboardText(_THIS)
 { @autoreleasepool
 {
     NSPasteboard *pasteboard;
@@ -73,8 +71,7 @@ Cocoa_GetClipboardText(_THIS)
     return text;
 }}
 
-SDL_bool
-Cocoa_HasClipboardText(_THIS)
+SDL_bool Cocoa_HasClipboardText(_THIS)
 {
     SDL_bool result = SDL_FALSE;
     char *text = Cocoa_GetClipboardText(_this);
@@ -85,8 +82,7 @@ Cocoa_HasClipboardText(_THIS)
     return result;
 }
 
-void
-Cocoa_CheckClipboardUpdate(SDL_VideoData * data)
+void Cocoa_CheckClipboardUpdate(SDL_VideoData * data)
 { @autoreleasepool
 {
     NSPasteboard *pasteboard;
