@@ -41,7 +41,7 @@ extern "C" {
 #include "SDL_bevents.h"
 
 static SDL_INLINE SDL_BWin *_ToBeWin(SDL_Window *window) {
-    return ((SDL_BWin*)(window->driverdata));
+    return (SDL_BWin *)(window->driverdata);
 }
 
 /* FIXME: Undefined functions */
@@ -54,8 +54,7 @@ static SDL_INLINE SDL_BWin *_ToBeWin(SDL_Window *window) {
 
 /* End undefined functions */
 
-static SDL_VideoDevice *
-HAIKU_CreateDevice(void)
+static SDL_VideoDevice * HAIKU_CreateDevice(void)
 {
     SDL_VideoDevice *device;
     /*SDL_VideoData *data;*/
@@ -141,8 +140,7 @@ void HAIKU_DeleteDevice(SDL_VideoDevice * device)
     SDL_free(device);
 }
 
-static SDL_Cursor *
-HAIKU_CreateSystemCursor(SDL_SystemCursor id)
+static SDL_Cursor * HAIKU_CreateSystemCursor(SDL_SystemCursor id)
 {
     SDL_Cursor *cursor;
     BCursorID cursorId = B_CURSOR_ID_SYSTEM_DEFAULT;
@@ -176,14 +174,12 @@ HAIKU_CreateSystemCursor(SDL_SystemCursor id)
     return cursor;
 }
 
-static SDL_Cursor *
-HAIKU_CreateDefaultCursor()
+static SDL_Cursor * HAIKU_CreateDefaultCursor()
 {
     return HAIKU_CreateSystemCursor(SDL_SYSTEM_CURSOR_ARROW);
 }
 
-static void
-HAIKU_FreeCursor(SDL_Cursor * cursor)
+static void HAIKU_FreeCursor(SDL_Cursor * cursor)
 {
     if (cursor->driverdata) {
         delete (BCursor*) cursor->driverdata;
@@ -191,14 +187,13 @@ HAIKU_FreeCursor(SDL_Cursor * cursor)
     SDL_free(cursor);
 }
 
-static SDL_Cursor *
-HAIKU_CreateCursor(SDL_Surface * surface, int hot_x, int hot_y)
+static SDL_Cursor * HAIKU_CreateCursor(SDL_Surface * surface, int hot_x, int hot_y)
 {
     SDL_Cursor *cursor;
     SDL_Surface *converted;
 
     converted = SDL_ConvertSurfaceFormat(surface, SDL_PIXELFORMAT_ARGB8888, 0);
-    if (!converted) {
+    if (converted == NULL) {
         return NULL;
     }
 
@@ -220,8 +215,9 @@ static int HAIKU_ShowCursor(SDL_Cursor *cursor)
 {
 	SDL_Mouse *mouse = SDL_GetMouse();
 
-	if (!mouse)
+	if (mouse == NULL) {
 		return 0;
+	}
 
 	if (cursor) {
 		BCursor *hCursor = (BCursor*)cursor->driverdata;
@@ -235,11 +231,10 @@ static int HAIKU_ShowCursor(SDL_Cursor *cursor)
 	return 0;
 }
 
-static int
-HAIKU_SetRelativeMouseMode(SDL_bool enabled)
+static int HAIKU_SetRelativeMouseMode(SDL_bool enabled)
 {
     SDL_Window *window = SDL_GetMouseFocus();
-    if (!window) {
+    if (window == NULL) {
       return 0;
     }
 
@@ -259,8 +254,9 @@ HAIKU_SetRelativeMouseMode(SDL_bool enabled)
 static void HAIKU_MouseInit(_THIS)
 {
 	SDL_Mouse *mouse = SDL_GetMouse();
-	if (!mouse)
+	if (mouse == NULL) {
 		return;
+	}
 	mouse->CreateCursor = HAIKU_CreateCursor;
 	mouse->CreateSystemCursor = HAIKU_CreateSystemCursor;
 	mouse->ShowCursor = HAIKU_ShowCursor;
@@ -292,7 +288,7 @@ int HAIKU_VideoInit(_THIS)
 #endif
 
     /* We're done! */
-    return (0);
+    return 0;
 }
 
 void HAIKU_VideoQuit(_THIS)
@@ -309,7 +305,7 @@ int HAIKU_OpenURL(const char *url)
 {
     BUrl burl(url);
     const status_t rc = burl.OpenWithPreferredApplication(false);
-    return (rc == B_NO_ERROR) ? 0 : SDL_SetError("URL open failed (err=%d)", (int) rc);
+    return (rc == B_NO_ERROR) ? 0 : SDL_SetError("URL open failed (err=%d)", (int)rc);
 }
 
 #ifdef __cplusplus
